@@ -36,7 +36,7 @@
 
 void	m_version()
 {
-	static char rcsid[] = "$Id: version.c,v 1.9 1994/03/24 00:04:05 des Exp $";
+	static char rcsid[] = "$Id: version.c,v 1.1.1.1 2003/06/23 18:31:42 cees Exp $";
 
 	printf("Meshach matrix library version 1.2b\n");
 	printf("RCS id: %s\n",rcsid);
@@ -63,11 +63,13 @@ void	m_version()
 	printf("EJP: added prototypes to header files\n");
 	printf("EJP: removed note about machine.van in configure.[h|hin] \n");
 	printf("EJP: (seems to be missing)\n");
-	printf("EJP: meminfo.h: removed MEM_STAT_REG and mem_stat_free()\n");
-	printf("EJP: -- they caused many warnings\n");
 }
 
 /* $Log: version.c,v $
+/* Revision 1.1.1.1  2003/06/23 18:31:42  cees
+/* Verbatim import gstat-2.4.2.tar.gz as downloaded from www.gstat.org
+/* at Mon Jun 23 20:52:05 CEST 2003
+/*
  * Revision 1.9  1994/03/24  00:04:05  des
  * Added notes on changes to spILUfactor() and px_inv().
  *
